@@ -1,6 +1,7 @@
 package api
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -9,9 +10,8 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/cli/cli/v2/internal/ghinstance"
-	"github.com/cli/go-gh"
-	ghAPI "github.com/cli/go-gh/pkg/api"
+	ghAPI "github.com/cli/go-gh/v2/pkg/api"
+	ghauth "github.com/cli/go-gh/v2/pkg/auth"
 )
 
 const (
@@ -39,11 +39,11 @@ func (c *Client) HTTP() *http.Client {
 }
 
 type GraphQLError struct {
-	ghAPI.GQLError
+	*ghAPI.GraphQLError
 }
 
 type HTTPError struct {
-	ghAPI.HTTPError
+	*ghAPI.HTTPError
 	scopesSuggestion string
 }
 
@@ -51,46 +51,58 @@ func (err HTTPError) ScopesSuggestion() string {
 	return err.scopesSuggestion
 }
 
-// GraphQL performs a GraphQL request and parses the response. If there are errors in the response,
-// GraphQLError will be returned, but the data will also be parsed into the receiver.
+// GraphQL performs a GraphQL request using the query string and parses the response into data receiver. If there are errors in the response,
+// GraphQLError will be returned, but the receiver will also be partially populated.
 func (c Client) GraphQL(hostname string, query string, variables map[string]interface{}, data interface{}) error {
 	opts := clientOptions(hostname, c.http.Transport)
 	opts.Headers[graphqlFeatures] = features
-	gqlClient, err := gh.GQLClient(&opts)
+	gqlClient, err := ghAPI.NewGraphQLClient(opts)
 	if err != nil {
 		return err
 	}
 	return handleResponse(gqlClient.Do(query, variables, data))
 }
 
-// GraphQL performs a GraphQL mutation and parses the response. If there are errors in the response,
-// GraphQLError will be returned, but the data will also be parsed into the receiver.
+// Mutate performs a GraphQL mutation based on a struct and parses the response with the same struct as the receiver. If there are errors in the response,
+// GraphQLError will be returned, but the receiver will also be partially populated.
 func (c Client) Mutate(hostname, name string, mutation interface{}, variables map[string]interface{}) error {
 	opts := clientOptions(hostname, c.http.Transport)
 	opts.Headers[graphqlFeatures] = features
-	gqlClient, err := gh.GQLClient(&opts)
+	gqlClient, err := ghAPI.NewGraphQLClient(opts)
 	if err != nil {
 		return err
 	}
 	return handleResponse(gqlClient.Mutate(name, mutation, variables))
 }
 
-// GraphQL performs a GraphQL query and parses the response. If there are errors in the response,
-// GraphQLError will be returned, but the data will also be parsed into the receiver.
+// Query performs a GraphQL query based on a struct and parses the response with the same struct as the receiver. If there are errors in the response,
+// GraphQLError will be returned, but the receiver will also be partially populated.
 func (c Client) Query(hostname, name string, query interface{}, variables map[string]interface{}) error {
 	opts := clientOptions(hostname, c.http.Transport)
 	opts.Headers[graphqlFeatures] = features
-	gqlClient, err := gh.GQLClient(&opts)
+	gqlClient, err := ghAPI.NewGraphQLClient(opts)
 	if err != nil {
 		return err
 	}
 	return handleResponse(gqlClient.Query(name, query, variables))
 }
 
+// QueryWithContext performs a GraphQL query based on a struct and parses the response with the same struct as the receiver. If there are errors in the response,
+// GraphQLError will be returned, but the receiver will also be partially populated.
+func (c Client) QueryWithContext(ctx context.Context, hostname, name string, query interface{}, variables map[string]interface{}) error {
+	opts := clientOptions(hostname, c.http.Transport)
+	opts.Headers[graphqlFeatures] = features
+	gqlClient, err := ghAPI.NewGraphQLClient(opts)
+	if err != nil {
+		return err
+	}
+	return handleResponse(gqlClient.QueryWithContext(ctx, name, query, variables))
+}
+
 // REST performs a REST request and parses the response.
 func (c Client) REST(hostname string, method string, p string, body io.Reader, data interface{}) error {
 	opts := clientOptions(hostname, c.http.Transport)
-	restClient, err := gh.RESTClient(&opts)
+	restClient, err := ghAPI.NewRESTClient(opts)
 	if err != nil {
 		return err
 	}
@@ -99,7 +111,7 @@ func (c Client) REST(hostname string, method string, p string, body io.Reader, d
 
 func (c Client) RESTWithNext(hostname string, method string, p string, body io.Reader, data interface{}) (string, error) {
 	opts := clientOptions(hostname, c.http.Transport)
-	restClient, err := gh.RESTClient(&opts)
+	restClient, err := ghAPI.NewRESTClient(opts)
 	if err != nil {
 		return "", err
 	}
@@ -140,18 +152,20 @@ func (c Client) RESTWithNext(hostname string, method string, p string, body io.R
 }
 
 // HandleHTTPError parses a http.Response into a HTTPError.
+//
+// The caller is responsible to close the response body stream.
 func HandleHTTPError(resp *http.Response) error {
 	return handleResponse(ghAPI.HandleHTTPError(resp))
 }
 
-// handleResponse takes a ghAPI.HTTPError or ghAPI.GQLError and converts it into an
+// handleResponse takes a ghAPI.HTTPError or ghAPI.GraphQLError and converts it into an
 // HTTPError or GraphQLError respectively.
 func handleResponse(err error) error {
 	if err == nil {
 		return nil
 	}
 
-	var restErr ghAPI.HTTPError
+	var restErr *ghAPI.HTTPError
 	if errors.As(err, &restErr) {
 		return HTTPError{
 			HTTPError: restErr,
@@ -162,10 +176,10 @@ func handleResponse(err error) error {
 		}
 	}
 
-	var gqlErr ghAPI.GQLError
+	var gqlErr *ghAPI.GraphQLError
 	if errors.As(err, &gqlErr) {
 		return GraphQLError{
-			GQLError: gqlErr,
+			GraphQLError: gqlErr,
 		}
 	}
 
@@ -184,12 +198,11 @@ func ScopesSuggestion(resp *http.Response) string {
 // EndpointNeedsScopes adds additional OAuth scopes to an HTTP response as if they were returned from the
 // server endpoint. This improves HTTP 4xx error messaging for endpoints that don't explicitly list the
 // OAuth scopes they need.
-func EndpointNeedsScopes(resp *http.Response, s string) *http.Response {
+func EndpointNeedsScopes(resp *http.Response, s string) {
 	if resp.StatusCode >= 400 && resp.StatusCode < 500 {
 		oldScopes := resp.Header.Get("X-Accepted-Oauth-Scopes")
 		resp.Header.Set("X-Accepted-Oauth-Scopes", fmt.Sprintf("%s, %s", oldScopes, s))
 	}
-	return resp
 }
 
 func generateScopesSuggestion(statusCode int, endpointNeedsScopes, tokenHasScopes, hostname string) string {
@@ -237,7 +250,7 @@ func generateScopesSuggestion(statusCode int, endpointNeedsScopes, tokenHasScope
 		return fmt.Sprintf(
 			"This API operation needs the %[1]q scope. To request it, run:  gh auth refresh -h %[2]s -s %[1]s",
 			s,
-			ghinstance.NormalizeHostname(hostname),
+			ghauth.NormalizeHostname(hostname),
 		)
 	}
 
