@@ -1,9 +1,9 @@
 package label
 
 import (
-	"reflect"
-	"strings"
 	"time"
+
+	"github.com/cli/cli/v2/pkg/cmdutil"
 )
 
 var labelFields = []string{
@@ -28,24 +28,6 @@ type label struct {
 	UpdatedAt   time.Time `json:"updatedAt"`
 }
 
-// ExportData implements cmdutil.exportable
 func (l *label) ExportData(fields []string) map[string]interface{} {
-	v := reflect.ValueOf(l).Elem()
-	data := map[string]interface{}{}
-
-	for _, f := range fields {
-		switch f {
-		default:
-			sf := fieldByName(v, f)
-			data[f] = sf.Interface()
-		}
-	}
-
-	return data
-}
-
-func fieldByName(v reflect.Value, field string) reflect.Value {
-	return v.FieldByNameFunc(func(s string) bool {
-		return strings.EqualFold(field, s)
-	})
+	return cmdutil.StructExportData(l, fields)
 }
